@@ -16,23 +16,21 @@
 #'
 #' @return Returns the complete output of the exploratory analysis: i) The processed, or filtered/normalized data ii) Statistical output containing results for the parametric (limma+ANOVA) and non-parametric tests (Wilcoxon+Kruskal-Wallis+PERMANOVA), along with statistical tests for heteroscedasticity, iii) Quality metrics for the input samples iv) QC plots and exploratory visualizations.
 #' @importFrom openxlsx write.xlsx  read.xlsx
-#' @importFrom grDevices  dev.off bmp
-#' @importFrom circlize colorRamp2
+#' @importFrom grDevices  dev.off bmp colorRampPalette
 #' @importFrom stringr str_trunc
 #' @importFrom dplyr select  group_by  group_modify everything  %>%
 #' @importFrom tidyr gather pivot_longer
 #' @importFrom broom tidy
 #' @importFrom reshape2 melt
 #' @importFrom ggpubr ggarrange
-#' @importFrom ggplot2 ggplot ggsave geom_violin scale_color_gradient element_line theme_linedraw scale_fill_manual scale_color_manual aes geom_histogram element_rect geom_point xlab ylab ggtitle theme_bw theme_minimal theme element_text guides guide_legend geom_boxplot labs theme_classic element_blank geom_jitter position_jitter
+#' @importFrom ggplot2 ggplot ggsave geom_smooth geom_violin scale_color_gradient element_line theme_linedraw scale_fill_manual scale_color_manual aes geom_histogram element_rect geom_point xlab ylab ggtitle theme_bw theme_minimal theme element_text guides guide_legend geom_boxplot labs theme_classic element_blank geom_jitter position_jitter
 #' @importFrom VIM kNN
 #' @importFrom stats kruskal.test p.adjust prcomp complete.cases sd wilcox.test friedman.test rnorm bartlett.test model.matrix heatmap median na.omit
 #' @importFrom forcats fct_inorder
 #' @importFrom limma topTable eBayes contrasts.fit normalizeCyclicLoess normalizeCyclicLoess lmFit normalizeQuantiles duplicateCorrelation
-#' @importFrom ComplexHeatmap HeatmapAnnotation anno_block draw Heatmap
+#' @importFrom pheatmap pheatmap
 #' @importFrom grid gpar
 #' @importFrom car leveneTest
-#' @importFrom vsn meanSdPlot
 #' @importFrom missRanger missRanger
 #' @importFrom utils read.delim
 #' @importFrom vegan adonis2
@@ -41,8 +39,14 @@
 #' #Example of running the function with paths for two groups.
 #' # The file path is a placeholder, replace it with an actual file.
 #'
+#'
+#'
 #' proteinGroups.txt <- system.file("extdata", "proteinGroups.txt", package = "ProtE")
-#' maximum_quantum(file = proteinGroups.txt,
+#' # Copy the file to a temporary directory for CRAN checks
+#' temp_file <- file.path(tempdir(), "proteinGroups.txt")
+#' file.copy(proteinGroups.txt, temp_file, overwrite = TRUE)
+#'
+#' maximum_quantum(file = temp_file,
 #'        group_names = c("Healthy","Control"),
 #'        samples_per_group = c(4,4), filtering_value = 80)
 #'
@@ -60,7 +64,7 @@ maximum_quantum <- function(file,
                       parametric= FALSE,
                       significance = "p")
 {
-  group1 = group2 = Accession =Description =Symbol= df4_wide =X =Y = percentage=Sample= variable =.= g1.name =g2.name= g3.name =g4.name= g5.name =g6.name= g7.name= g8.name =g9.name =group3= group4= group5= group6 =group7= group8= group9 =key =value = NULL
+  group1 = group2 = Accession =Description = Mean = SD = Symbol= df4_wide =X =Y = percentage=Sample= variable =.= g1.name =g2.name= g3.name =g4.name= g5.name =g6.name= g7.name= g8.name =g9.name =group3= group4= group5= group6 =group7= group8= group9 =key =value = NULL
 
 message("The ProtE process starts now!")
 
@@ -69,8 +73,15 @@ message("The ProtE process starts now!")
     stop("The length of 'samples_per_group' must match 'groups_number'") }
   for (i in 1:groups_number) {
     assign(paste0("g",i,".name"),group_names[[i]])}
-  dataspace <- read.delim(file = file, header = TRUE, sep = "\t")
-  dataspace <- dataspace[!grepl("^;",dataspace$Protein.IDs),]
+
+  if(grepl("\\.txt$", file)) {
+    dataspace <- utils::read.delim2(file, header = TRUE, sep = "\t")
+  }
+  else if(grepl("\\.xlsx$", file)) {
+    dataspace <- openxlsx::read.xlsx(file)
+  } else {stop("Error, the file you provided is not on .txt or .xlsx format")}
+
+    dataspace <- dataspace[!grepl("^;",dataspace$Protein.IDs),]
   dataspace <- dataspace[complete.cases(dataspace[,1]),]
   if("Reverse" %in% colnames(dataspace)) {
   dataspace <- dataspace[dataspace$Reverse == ""|is.na(dataspace$Reverse) == TRUE,]
@@ -223,19 +234,37 @@ message("The ProtE process starts now!")
 
   if (normalization %in% c(FALSE,"median", "Total_Ion_Current", "PPM") ){
     log.dataspace <- log(dataspace[,-c(1:2)]+1,2)
-  sdrankplot_path <- file.path(path_resplot, "meanSdPlot.bmp")
-  bmp(sdrankplot_path, width = 1500, height = 1080, res = 150)
-  suppressWarnings(vsn::meanSdPlot(as.matrix(log.dataspace[, -1:-2])))
-    dev.off()
+    row_means <- rowMeans(log.dataspace, na.rm = TRUE)
+    row_sds <- apply(log.dataspace, 1, sd, na.rm = TRUE)
+    plot_data <- data.frame(Mean = row_means, SD = row_sds)
+    meansd <- ggplot(plot_data, aes(x = Mean, y = SD)) +
+      geom_point(alpha = 0.5, color = "blue") +
+      suppressMessages(geom_smooth(method = "loess", color = "red", se = FALSE)) +
+      theme_minimal() +
+      labs(title = "Mean-SD Plot on the log2 normalized data", x = "Mean Expression", y = "Standard Deviation")
+    meansd
+    ggplot2::ggsave("meanSdPlot.bmp", plot = meansd,  path = path_resplot,
+                    scale = 1, width = 5, height = 4, units = "in",
+                    dpi = 300, limitsize = TRUE)
+
     message("Creating Mean-SD plot on the log2 data.")
   } else {
-    sdrankplot_path <- file.path(path_resplot, "meanSdPlot.png")
-    bmp(sdrankplot_path, width = 1500, height = 1080, res = 150)
-    suppressWarnings(vsn::meanSdPlot(as.matrix(dataspace[, -1:-2])))
-    dev.off()
+    row_means <- rowMeans(dataspace[,-c(1,2)], na.rm = TRUE)
+    row_sds <- apply(dataspace[,-c(1,2)], 1, sd, na.rm = TRUE)
+    plot_data <- data.frame(Mean = row_means, SD = row_sds)
+    meansd <- ggplot(plot_data, aes(x = Mean, y = SD)) +
+      geom_point(alpha = 0.5, color = "blue") +
+      geom_smooth(method = "loess", color = "red", se = FALSE) +
+      theme_minimal() +
+      labs(title = "Mean-SD Plot on the log2 normalized data", x = "Mean Expression", y = "Standard Deviation")
+    meansd
+    ggplot2::ggsave("meanSdPlot.bmp", plot = meansd,  path = path_resplot,
+                    scale = 1, width = 5, height = 4, units = "in",
+                    dpi = 300, limitsize = TRUE)
     message("Creating Mean-SD plot.")
   }
 
+
   name_dataspace <-  dataspace[, -1:-2]
 
 
@@ -803,27 +832,27 @@ dataspace$percentage
 
       range_limit <- min(abs(min(zlog.dataspace.sig, na.rm = TRUE)), abs(max(zlog.dataspace.sig, na.rm = TRUE)))
 
-      mycols <- circlize::colorRamp2(
-        c(-range_limit, 0, range_limit),
-        c("blue", "white", "red")
-      )
-      heatmap_data<- ComplexHeatmap::Heatmap(as.matrix(zlog.dataspace.sig),
-                                             cluster_rows = TRUE,
-                                             cluster_columns = FALSE,
-                                             show_row_names = FALSE,
-                                             show_column_names = FALSE,
-                                             column_split = groups_list_f,
-                                             top_annotation = ComplexHeatmap::HeatmapAnnotation(foo = anno_block(gp = gpar(fill = 2:(groups_number+1)),
-                                                                                                                 labels = group_names, labels_gp = gpar(col = "black", fontsize = 10))),
-                                             col = mycols, column_title = NULL,
-                                             heatmap_legend_param = list(
-                                               title = "Z-Score",
-                                               color_bar = "continuous"
-                                             ))
+
+      breaks <- seq(-range_limit, range_limit, length.out = 101)
+      mycols_vector <- grDevices::colorRampPalette(c("blue", "white", "red"))(100)
+
+      annotation_col <- data.frame(Group = factor(groups_list_f))
+      rownames(annotation_col) <- colnames(zlog.dataspace.sig)
+      colnames(annotation_col) <- " "
       bmp_file_path <- file.path(path_resplot, "heatmap.bmp")
       bmp(bmp_file_path,width = 1500, height = 1080, res = 150)
-      ComplexHeatmap::draw(heatmap_data)
-
+      pheatmap(as.matrix(zlog.dataspace.sig),
+               cluster_rows = TRUE,
+               cluster_cols = FALSE,
+               show_rownames = FALSE,
+               show_colnames = FALSE,
+               annotation_col = annotation_col,
+               color = mycols_vector,
+               breaks = breaks,
+               legend = TRUE,
+               legend_labels = NULL,
+               annotation_legend = TRUE,
+               scale = "none")
       dev.off()
 
       message("A heatmap with the differentially expressed proteins was created as heatmap.bmp")
@@ -849,7 +878,7 @@ dataspace$percentage
       pca.data$Group<-factor(pca.data$Group, levels=Group2)
 
       pca.sig<-ggplot2::ggplot(data=pca.data, aes(x=X, y=Y, label=Sample))+
-        geom_point(aes(color=Group), size = 2, alpha = 1)+
+      suppressWarnings(geom_point(aes(color=Group), size = 2, alpha = 1))+
         xlab(paste("PC1 - ", pca.var.per[1], "%", sep=""))+
         ylab(paste("PC2 - ", pca.var.per[2], "%", sep=""))+
         ggtitle("Statistically significant proteins")+
